@@ -131,6 +131,7 @@ static GtkWidget *New( GtkWidget *widget, GtkWidget *notebook )
 		ptr = getcwd( buf, ( size_t ) size );
 
         vte_terminal_fork_command( VTE_TERMINAL( doc->Term ), NULL, NULL, NULL, ptr, TRUE, TRUE, TRUE );
+	//vte_terminal_fork_command_full( VTE_TERMINAL( doc->Term ), VTE_PTY_DEFAULT, ptr, NULL, NULL, NULL, NULL, NULL, NULL, NULL );
 	#endif
 	
 	gtk_paned_set_position( GTK_PANED( doc->Paned ), 450 );
@@ -372,7 +373,7 @@ static void Template( GtkWidget *widget, GtkWidget *notebook )
 {
 	gchar *templates = g_build_filename( g_get_home_dir( ), "/.config/X2/templates/", NULL );
 	GDir *d = g_dir_open( templates, 0, NULL );
-	gchar *dir = g_dir_read_name( d );	
+	const gchar *dir = g_dir_read_name( d );	
 
 	if( dir == NULL )
 		return;
@@ -1014,7 +1015,7 @@ static void Populate_CMB( GtkWidget *cmb )
 
 	for( ; ; )
 	{
-		gchar *tmp = g_dir_read_name( d );	
+		const gchar *tmp = g_dir_read_name( d );	
 
 		if( tmp != NULL )
 			gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT( cmb ), tmp );
@@ -1041,7 +1042,7 @@ static void Catch_Keypress( GtkWidget *widget, GdkEvent *event, GtkWidget *noteb
 static void LoadTemplate( GtkWidget *widget, GtkWidget *notebook )
 {
 	struct node *tmp = g_object_get_data( G_OBJECT( gtk_notebook_get_nth_page( GTK_NOTEBOOK( notebook ), gtk_notebook_get_current_page( GTK_NOTEBOOK( notebook ) ) ) ), "document" );
-	gchar *template = g_build_filename( g_get_home_dir( ), "/.config/X2/templates/", gtk_combo_box_get_active_text( GTK_COMBO_BOX( tmp->templatecmb ) ), NULL );
+	gchar *template = g_build_filename( g_get_home_dir( ), "/.config/X2/templates/", gtk_combo_box_text_get_active_text( GTK_COMBO_BOX_TEXT( tmp->templatecmb ) ), NULL );
 	open_from( template, notebook );
 	gtk_widget_hide( tmp->templatebox );
 }
